{% extends "admin/change_list.html" %}
{% load static i18n django_horizontal_list_filter django_simple_tags %}


{% block search %}
{% if cl.filter_specs or cl.model_admin.search_fields %}
<div class="django-horizontal-list-filter-bar">
    {% for spec in cl.filter_specs %}
    <div class="django-horizontal-list-filter-group">
        {% django_horizontal_list_filter cl spec %}
    </div>
    {% endfor %}

    {% if cl.model_admin.search_fields %}
    <div class="django-horizontal-list-filter-group">
        <label>{% django_horizontal_list_filter_search_box_label cl %}</label>
        <input name="q" value="{{request.GET.q}}" />
    </div>
    {% endif %}

    <div class="django-horizontal-list-filter-group">
        <a class="django-horizontal-list-filter-search">{% trans "Search" %}</a>
        <a class="django-horizontal-list-filter-reset">{% trans "Reset" %}</a>
    </div>
    <div class="django-horizontal-list-filter-group-clear"></div>
</div>
{% endif %}
{% endblock %}


{% block content %}
{% reset cl "has_filters" False %}
{{block.super}}
{% endblock %}