.django-horizontal-list-filter-bar {
    width: auto;
    padding: 10px;
    background-color: #f8f8f8;
    color: #666;
}
.filtered .django-horizontal-list-filter-bar {
    margin-right: 280px;
}
.django-horizontal-list-filter-bar-title {
    background-color: #79aec8;
    color: #fff;
    font-weight: 400;
    font-size: 14px;
    text-transform: uppercase;
    letter-spacing: 0.5px;
    padding: 5px 15px;
    margin-bottom: 12px;
    border-bottom: none;
}
.django-horizontal-list-filter-group {
    display: inline-block;
    height: 30px;
    line-height: 30px;
    padding: 10px 10px 10px 0;
}
.django-horizontal-list-filter-group-clear {
    clear: both;
    height: 0;
    line-height: 0;
}

.django-horizontal-list-filter-group h3 {
    display: inline-block;
}
.django-horizontal-list-filter-group > label {
    padding-right: 10px;
}
.django-horizontal-list-filter-group > label.small {
    width: 50px;
}
.django-horizontal-list-filter-group > select {
    margin-right: 20px;
    max-width: 300px;
}
.django-horizontal-list-filter-group > input {
    border: 1px solid #ccc;
    border-radius: 4px;
    padding: 5px 6px;
    margin-top: 0;
    margin-right: 20px;
}

.django-horizontal-list-filter-group > .django-horizontal-list-filter-search {
    margin-right: 20px;
    background: #79aec8;
    padding: 8px 15px;
    border: none;
    border-radius: 4px;
    color: #fff;
    cursor: pointer;
}
.django-horizontal-list-filter-group > .django-horizontal-list-filter-reset {
    background: #999;
    padding: 8px 15px;
    border: none;
    border-radius: 4px;
    color: #fff;
    cursor: pointer;
}
#changelist #toolbar {
    margin: 0;
    padding: 0;
}

/* fix filter block that using ul */
.django-horizontal-list-filter-group ul {
    display: inline-block;
    list-style: none;
}
.django-horizontal-list-filter-group ul > li {
    list-style-type: none;
}
.module .django-horizontal-list-filter-group ul,
.module .django-horizontal-list-filter-group ol {
    margin-left: 0;
    padding-left: 0;
    padding-right: 0;
}
